@@ -210,7 +210,7 @@ FILE *fp;
   /* Who knows... even DIALD might get internationalized.
      Not that I'm expecting miracles :-)                         */
   do {
-    n = fscanf(fp, _(" %s %s %d %d:%d:%d %d %*s %s"),
+    n = fscanf(fp, _(" %s %s %d %d:%d:%d %d %*[^:]: %s"),
                    s, b, &day, &hour, &min, &sec, &year, id);
     if (n == EOF) return duration;
     if (strcmp(id, _("Disconnected."))) {
@@ -225,7 +225,7 @@ FILE *fp;
     exit(1);
   }
   do_calculations(dow,T_IN_SEC(h,m,se),duration);
-  fscanf(fp, _(" IP transmited %*d bytes and received %*d bytes."));
+  fscanf(fp, _(" IP %*s %*d bytes and %*s %*d bytes."));
   return duration;
 }
 
@@ -327,6 +327,9 @@ char *s;
     } else if (strcmp(buf, "FILE") == 0) {
       fscanf(fp, " %[^ ;\n]", buf);
       pres.log_file = strdup(buf);
+    } else if (strcmp(buf, "FIFO") == 0) {
+      fscanf(fp, " %[^ ;\n]", buf);
+      pres.comm_ch = strdup(buf);
     } else if (strcmp(buf, "TIME") == 0) {
       char s1[24], s2[24];
 
@@ -401,7 +404,7 @@ main (argc, argv)
 
     FiFo = OpenFifo(pres.comm_ch);
     FoFi = OpenFifo(ff_file);
-    fprintf(FiFo, "monitor %s\n", ff_file), fflush(FiFo);
+    fprintf(FiFo, "monitor 7 %s\n", ff_file), fflush(FiFo);
 
     /* First, let us try read some default setup information, if it exists */
     /* it is either in the users home directory, or a site default inside  */
@@ -556,7 +559,7 @@ void Quit()
 {
   extern void exit();
 
-  fprintf(FiFo, "monitor\n"), fflush(FiFo);
+  fprintf(FiFo, "monitor 0\n"), fflush(FiFo);
   fclose(FiFo);
   fclose(FoFi);
   if (pres.fifo_file == NULL)
@@ -570,10 +573,10 @@ void Monitor()
 {
   if (int_counter >= 20) {
     MessagePrintf(message, _("\nAsking to reopen message channel"));
-    fprintf(FiFo, "monitor %s\n", ff_file);
+    fprintf(FiFo, "monitor 7 %s\n", ff_file);
   } else {
     MessagePrintf(message, _("\nClosing message channel"));
-    fprintf(FiFo, "monitor \n");
+    fprintf(FiFo, "monitor 0 \n");
   }
   fflush(FiFo);
 }
@@ -628,7 +631,7 @@ int status;
   }
 }
 
-/* Executed once every second */
+/* Executed every 200 ms */
 void Timer()
 {
   static char s[64];
@@ -636,17 +639,13 @@ void Timer()
 
   fstat(fileno(FoFi), &st);
   if (st.st_size > 8) {
-    if (int_counter) {
-      if (int_counter >= 50 || ++int_counter == 0)
-	MessagePrintf(message, "\n"), int_counter = 0;
-    }
     fscanf(FoFi, " %s", s);
     if (strcmp(s, "STATE") == 0) {
       fscanf(FoFi, " %s", s);
       if (strcmp(s, _("STOP_LINK")) == 0) LinkCounter(0);
       else if (strcmp(s, _("START_LINK")) == 0) LinkCounter(1);
-      else if (strcmp(s, "UP") == 0) SetLabel(bState, "Down");
-      else if (strcmp(s, "DOWN") == 0) SetLabel(bState, " Up ");
+      else if (strcmp(s, "UP") == 0) SetLabel(bState,"Down"),LinkCounter(1);
+      else if (strcmp(s, "DOWN") == 0) SetLabel(bState," Up "),LinkCounter(0);
       SetLabel(State, s);
     } else if (strcmp(s, "QUEUE") == 0) {
       *s = 0;
@@ -655,6 +654,10 @@ void Timer()
     } else if (strcmp(s, "STATUS") == 0) {
       int a, b;
 
+      if (int_counter) {
+	if (int_counter >= 50 || ++int_counter == 0)
+	  MessagePrintf(message, "\n"), int_counter = 0;
+      }
       fscanf(FoFi, " %d %d", &a, &b);
       ReadN(s, 4);
       SetLabel(mImp, s);
@@ -702,8 +705,10 @@ void LineUp(Widget w, XtPointer client_d, XtPointer call_d)
 {
   if (link_state)
     fprintf(FiFo, "down\n");
-  else
+  else {
+    fprintf(FiFo, "unblock\n");
     fprintf(FiFo, "up\n");
+  }
   fflush(FiFo);
 }
 
@@ -711,13 +716,13 @@ void Block(Widget w, XtPointer client_d, XtPointer call_d)
 {
   static int state = 0;
 
-  state = FifoCommandLabel(w, state, "block", "unblock");
+  state = FifoCommandLabel(w, state, " block ", "unblock");
 }
 
 void Force(Widget w, XtPointer client_d, XtPointer call_d)
 {
   static int state = 0;
 
-  state = FifoCommandLabel(w, state, "force", "unforce");
+  state = FifoCommandLabel(w, state, " force ", "unforce");
 }
 
